@@ -18,7 +18,6 @@ from twisted.internet import reactor
 from struct import unpack
 from twisted.python import log as tlog
 from subprocess import Popen
-from psycopg2 import connect
 from os import path
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
@@ -73,7 +72,7 @@ class QPostgresServer():
             def connectionMade(self):
                 self._state = 1
                 self._variables = {}
-                _q_s.logs.info(['servers', {'server': 'postgres_server', 'action': 'connection', 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port}])
+                _q_s.logs.info({'server': 'postgres_server', 'action': 'connection', 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
 
             def dataReceived(self, data):
                 if self._state == 1:
@@ -93,7 +92,7 @@ class QPostgresServer():
                             username = _q_s.username
                             password = _q_s.password
                             status = 'success'
-                        _q_s.logs.info(['servers', {'server': 'postgres_server', 'action': 'login', 'status': status, 'ip': self.transport.getPeer().host, 'port': self.transport.getPeer().port, 'username': username, 'password': password}])
+                        _q_s.logs.info({'server': 'postgres_server', 'action': 'login', 'status': status, 'src_ip': self.transport.getPeer().host, 'src_port': self.transport.getPeer().port, 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'username': username, 'password': password})
 
                     self.transport.loseConnection()
                 else:
@@ -125,7 +124,7 @@ class QPostgresServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'postgres_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port, 'username': self.username, 'password': self.password}])
+            self.logs.info({'server': 'postgres_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port, 'username': self.username, 'password': self.password})
 
             if status == 'success':
                 return True
@@ -135,16 +134,6 @@ class QPostgresServer():
         else:
             self.postgres_server_main()
 
-    def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
-            _ip = ip or self.ip
-            _port = port or self.port
-            _username = username or self.username
-            _password = password or self.password
-            x = connect(host=_ip, port=_port, user=_username, password=_password)
-        except BaseException:
-            pass
-
     def close_port(self):
         ret = close_port_wrapper('postgres_server', self.ip, self.port, self.logs)
         return ret
@@ -153,6 +142,17 @@ class QPostgresServer():
         ret = kill_server_wrapper('postgres_server', self.uuid, self.process)
         return ret
 
+    def test_server(self, ip=None, port=None, username=None, password=None):
+        try:
+            from psycopg2 import sql, connect
+            _ip = ip or self.ip
+            _port = port or self.port
+            _username = username or self.username
+            _password = password or self.password
+            x = connect(host=_ip, port=_port, user=_username, password=_password)
+        except BaseException:
+            pass
+
 
 if __name__ == '__main__':
     parsed = server_arguments()
