@@ -13,16 +13,12 @@
 from warnings import filterwarnings
 filterwarnings(action='ignore', module='.*OpenSSL.*')
 
-from twisted.internet.protocol import Protocol, Factory, DatagramProtocol
+from twisted.internet.protocol import DatagramProtocol
 from twisted.internet import reactor
-from struct import unpack, calcsize, pack
-from time import time
 from twisted.python import log as tlog
 from subprocess import Popen
-from psycopg2 import connect
 from os import path
 from scapy.all import SNMP
-from socket import socket, AF_INET, SOCK_DGRAM
 from honeypots.helper import close_port_wrapper, get_free_port, kill_server_wrapper, server_arguments, setup_logger, disable_logger, set_local_vars, check_if_server_is_running
 from uuid import uuid4
 
@@ -57,7 +53,6 @@ class QSNMPServer():
                 version = 'UnKnown'
                 community = 'UnKnown'
                 oids = 'UnKnown'
-                success = False
                 try:
                     parsed_snmp = SNMP(data)
                     community = parsed_snmp.community.val
@@ -68,12 +63,11 @@ class QSNMPServer():
                 return version, community, oids
 
             def datagramReceived(self, data, addr):
-                _q_s.logs.info(['servers', {'server': 'snmp_server', 'action': 'connection', 'status': 'fail', 'ip': addr[0], 'port': addr[1]}])
+                _q_s.logs.info({'server': 'snmp_server', 'action': 'connection', 'status': 'fail', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port})
                 version, community, oids = self.parse_snmp(data)
                 if version or community or oids:
-                    _q_s.logs.info(['servers', {'server': 'snmp_server', 'action': 'query', 'status': 'success', 'ip': addr[0], 'port': addr[1], 'version': version, 'community': community, 'oids':oids}])
+                    _q_s.logs.info({'server': 'snmp_server', 'action': 'query', 'status': 'success', 'src_ip': addr[0], 'src_port': addr[1], 'dst_ip': _q_s.ip, 'dst_port': _q_s.port, 'version': version, 'community': community, 'oids': oids})
                     self.transport.write('Error', addr)
-                    success = True
 
                 self.transport.loseConnection()
 
@@ -97,7 +91,7 @@ class QSNMPServer():
                 if self.process.poll() is None and check_if_server_is_running(self.uuid):
                     status = 'success'
 
-            self.logs.info(['servers', {'server': 'snmp_server', 'action': 'process', 'status': status, 'ip': self.ip, 'port': self.port}])
+            self.logs.info({'server': 'snmp_server', 'action': 'process', 'status': status, 'src_ip': self.ip, 'src_port': self.port})
 
             if status == 'success':
                 return True
@@ -107,12 +101,6 @@ class QSNMPServer():
         else:
             self.snmp_server_main()
 
-    def test_server(self, ip=None, port=None, username=None, password=None):
-        try:
-            pass
-        except BaseException:
-            pass
-
     def close_port(self):
         ret = close_port_wrapper('snmp_server', self.ip, self.port, self.logs)
         return ret
@@ -121,6 +109,12 @@ class QSNMPServer():
         ret = kill_server_wrapper('snmp_server', self.uuid, self.process)
         return ret
 
+    def test_server(self, ip=None, port=None, username=None, password=None):
+        try:
+            from socket import socket, AF_INET, SOCK_DGRAM
+        except BaseException:
+            pass
+
 
 if __name__ == '__main__':
     parsed = server_arguments()
